#line 2 "lex.yy.c"

#line 4 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE isdn_restart(isdn_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int isdn_leng;

extern FILE *isdn_in, *isdn_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up isdn_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up isdn_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via isdn_restart()), so that the user can continue scanning by
	 * just pointing isdn_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when isdn_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int isdn_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow isdn_wrap()'s to do buffer switches
 * instead of setting up a fresh isdn_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void isdn_restart (FILE *input_file  );
void isdn__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE isdn__create_buffer (FILE *file,int size  );
void isdn__delete_buffer (YY_BUFFER_STATE b  );
void isdn__flush_buffer (YY_BUFFER_STATE b  );
void isdn_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void isdn_pop_buffer_state (void );

static void isdn_ensure_buffer_stack (void );
static void isdn__load_buffer_state (void );
static void isdn__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER isdn__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE isdn__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE isdn__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE isdn__scan_bytes (yyconst char *bytes,int len  );

void *isdn_alloc (yy_size_t  );
void *isdn_realloc (void *,yy_size_t  );
void isdn_free (void *  );

#define yy_new_buffer isdn__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        isdn_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            isdn__create_buffer(isdn_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        isdn_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            isdn__create_buffer(isdn_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *isdn_in = (FILE *) 0, *isdn_out = (FILE *) 0;

typedef int yy_state_type;

extern int isdn_lineno;

int isdn_lineno = 1;

extern char *isdn_text;
#define yytext_ptr isdn_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up isdn_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	isdn_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 16
#define YY_END_OF_BUFFER 17
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[77] =
    {   0,
        0,    0,    0,    0,    0,    0,   17,   15,   12,   14,
       10,   11,    5,    5,   13,   15,    2,    3,    4,   16,
        6,    8,    6,   16,   16,    7,   16,   12,    0,   10,
        5,    5,    5,    2,    3,    0,    0,    8,    0,    0,
        6,    6,    0,    6,    0,    0,    0,    6,    5,    0,
        0,    0,    0,    0,    0,    8,    6,    0,    6,    0,
        6,    0,    9,    0,    5,    8,    8,    6,    6,    5,
        5,    5,    0,    1,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    6,    1,    1,    1,    1,    7,
        8,    1,    1,    1,    1,    1,    1,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    1,    1,    1,
       10,    1,    1,    1,   11,   11,   12,   13,   14,   11,
       11,   11,   15,   11,   11,   16,   11,   17,   11,   11,
       11,   11,   11,   11,   18,   11,   11,   11,   11,   11,
       19,   20,   21,    1,    1,    1,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   22,    1,   23,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[24] =
    {   0,
        1,    2,    3,    2,    4,    1,    1,    2,    5,    1,
        5,    5,    5,    5,    5,    5,    5,    5,    1,    1,
        1,    4,    4
    } ;

static yyconst flex_int16_t yy_base[87] =
    {   0,
        0,    0,   22,   23,   30,   52,  120,  306,   38,  306,
        0,  306,  110,   19,  306,  115,    0,   35,  306,   74,
       93,  306,   39,  112,  112,  306,  306,   42,  109,    0,
        0,  102,   36,    0,   45,  107,  131,  306,   59,  106,
      150,   62,  105,   63,  102,   99,  169,    0,   64,   66,
       67,  188,  207,    0,  100,   99,    0,   98,   86,   97,
        0,    0,  306,   96,   20,   89,    0,    0,   87,   72,
       84,  226,  245,  306,   81,  306,  265,  270,  275,   55,
      280,  285,  290,   46,  295,  300
    } ;

static yyconst flex_int16_t yy_def[87] =
    {   0,
       76,    1,   77,   77,   78,   78,   76,   76,   76,   76,
       79,   76,   80,   80,   76,   76,   81,   76,   76,   82,
       82,   76,   76,   83,   82,   76,   76,   76,   76,   79,
       84,   80,   80,   81,   76,   25,   85,   76,   86,   25,
       85,   86,   25,   76,   76,   83,   76,   21,   80,   41,
       41,   41,   86,   53,   53,   52,   41,   52,   53,   53,
       41,   47,   76,   76,   80,   52,   53,   41,   53,   80,
       80,   80,   76,   76,   76,    0,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76
    } ;

static yyconst flex_int16_t yy_nxt[330] =
    {   0,
        8,    9,   10,    9,    8,   11,    8,    8,    8,   12,
       13,   13,   13,   13,   14,   13,   13,   13,   15,   16,
       15,    8,   15,   18,   18,   18,   18,   31,   31,   19,
       19,   21,   22,   23,   24,   33,   35,   70,   35,   28,
       44,   28,   44,   28,   31,   28,   35,   49,   35,   25,
       31,   26,   27,   21,   22,   23,   24,   29,   45,   32,
       54,   29,   39,   59,   44,   42,   44,   51,   51,   39,
       39,   25,   31,   26,   27,   37,   38,   39,   55,   65,
       31,   60,   45,   73,   71,   52,   52,   59,   59,   42,
       42,   38,   31,   40,   41,   38,   42,   72,   62,   69,

       68,   38,   67,   47,   44,   60,   60,   61,   56,   38,
       31,   28,   43,   37,   48,   39,   47,   28,   31,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   40,   51,   38,   39,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       52,   57,   38,   42,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   58,
       62,   63,   62,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   64,   51,
       66,   39,   76,   76,   76,   76,   76,   76,   76,   76,

       76,   76,   76,   76,   76,   76,   76,   52,   54,   38,
       39,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   55,   73,   76,   73,
       76,   76,   74,   76,   31,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   75,   73,   76,   73,   76,
       76,   74,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   75,   17,   17,   17,   17,   17,
       20,   20,   20,   20,   20,   30,   30,   76,   30,   30,
       34,   76,   34,   34,   34,   36,   36,   36,   76,   36,
       46,   46,   46,   46,   46,   50,   50,   50,   76,   50,

       53,   53,   76,   76,   53,    7,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76
    } ;

static yyconst flex_int16_t yy_chk[330] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    4,    3,    4,   14,   65,    3,
        4,    5,    5,    5,    5,   14,   18,   65,   18,    9,
       23,    9,   23,   28,   33,   28,   35,   33,   35,    5,
       84,    5,    5,    6,    6,    6,    6,    9,   23,   80,
       39,   28,   39,   42,   44,   42,   44,   50,   51,   50,
       51,    6,   49,    6,    6,   20,   20,   20,   39,   49,
       70,   42,   44,   75,   70,   50,   51,   59,   69,   59,
       69,   66,   71,   20,   21,   21,   21,   71,   64,   60,

       58,   56,   55,   46,   45,   59,   69,   43,   40,   36,
       32,   29,   21,   25,   25,   25,   24,   16,   13,    7,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   25,   37,   37,   37,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       37,   41,   41,   41,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   41,
       47,   47,   47,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   47,   52,
       52,   52,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,   52,   53,   53,
       53,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   53,   72,    0,   72,
        0,    0,   72,    0,   72,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   72,   73,    0,   73,    0,
        0,   73,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   73,   77,   77,   77,   77,   77,
       78,   78,   78,   78,   78,   79,   79,    0,   79,   79,
       81,    0,   81,   81,   81,   82,   82,   82,    0,   82,
       83,   83,   83,   83,   83,   85,   85,   85,    0,   85,

       86,   86,    0,    0,   86,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int isdn__flex_debug;
int isdn__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *isdn_text;
#line 1 "isdnlexer.l"
#line 4 "isdnlexer.l"
/*
 * isdn4linux options file format lexer
 *
 * This file is part of ANT (Ant is Not a Telephone)
 *
 * Copyright 2002, 2003 Roland Stigge
 *
 * ANT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ANT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ANT; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#define YYSTYPE char*

/* GNU headers */
#include <string.h>
#include <libgen.h>

/* own headers */
#include "globals.h"
#include "isdnparser.h"
#include "isdnlexer.h"

typedef struct isdn_include_t isdn_include_t;
struct isdn_include_t {
  char* filename;
  YYLTYPE location;
  YY_BUFFER_STATE state;
  isdn_include_t* next;
};

isdn_include_t* isdn_include_list;
char* isdn_filename;
YYLTYPE isdn_lloc;

void isdn_locate();
/* exclusive start condition for C-style comments */


#line 588 "lex.yy.c"

#define INITIAL 0
#define _INCLUDE_ 1
#define _VALUE_ 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int isdn_wrap (void );
#else
extern int isdn_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( isdn_text, isdn_leng, 1, isdn_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( isdn_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( isdn_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, isdn_in))==0 && ferror(isdn_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(isdn_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int isdn_lex (void);

#define YY_DECL int isdn_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after isdn_text and isdn_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 60 "isdnlexer.l"


#line 742 "lex.yy.c"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! isdn_in )
			isdn_in = stdin;

		if ( ! isdn_out )
			isdn_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			isdn_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				isdn__create_buffer(isdn_in,YY_BUF_SIZE );
		}

		isdn__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of isdn_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 77 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 306 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 62 "isdnlexer.l"
{
                               isdn_locate();
                               BEGIN(_INCLUDE_);
			     }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 66 "isdnlexer.l"
{ /* got absolute or relative (to the current
                                * file) filename
				*/
			       isdn_include_t* temp = (isdn_include_t*)
			         malloc(sizeof(isdn_include_t));
			       isdn_include_t* i; /* iterator */
			       int loop_detected;
			       FILE* temp_in;
			       
                               isdn_locate();
			       temp->filename = isdn_filename;
			       temp->location = isdn_lloc;
			       temp->state = YY_CURRENT_BUFFER;
			       temp->next = isdn_include_list;
			       isdn_include_list = temp;

			       if (isdn_text[0] == '/') { /* absolute path */
			         isdn_filename = strdup(isdn_text);
			       } else { /* relative path */
			         char* path1 = strdup(isdn_filename); /* old
				                                         name */
				 char* path2 = dirname(path1); /* just dir */

				 asprintf(&isdn_filename, "%s/%s",
				          path2, isdn_text);
				 free(path1);
			       }

			       /* loop detection */
			       loop_detected = 0;
			       for (i = isdn_include_list;
			            i != NULL && !loop_detected;
				    i = i->next)
			       {
			         if (!strcmp(i->filename, isdn_filename))
				   loop_detected = 1;
			       }

			       if (loop_detected ||
			           !(temp_in = fopen(isdn_filename, "r")))
			       {
			         /* ignoring non-existent included file */
			         if (debug) {
				   if (loop_detected)
				     fprintf(stderr, "Loop detected ");
				   else
				     fprintf(stderr, "Error ");
				   fprintf(stderr,
				     "reading ISDN options file %s "
				     "from %s. Ignoring.\n",
				     isdn_filename, temp->filename);
				 }
				 /* recover to old buffer */
				 free(isdn_filename);
				 isdn_filename = temp->filename;
				 isdn_include_list = temp->next;
			         free(temp);
			       } else {
			         /* include file OK */
				 isdn_in = temp_in;
                                 if (debug)
                                   fprintf(stderr,
				     "Reading options file %s "
				     "from %s ...\n",
				     isdn_filename, temp->filename);
				 isdn__switch_to_buffer(isdn__create_buffer(isdn_in,YY_BUF_SIZE));
				 BEGIN(INITIAL);
				 isdn_lloc.first_line = 1;
				 isdn_lloc.last_line = 1;
				 isdn_lloc.first_column = 1;
				 isdn_lloc.last_column = 1;
			       }
                             }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(_INCLUDE_):
case YY_STATE_EOF(_VALUE_):
#line 140 "isdnlexer.l"
{ /* end of current file */
                               if (!isdn_include_list) { /* last buffer */
			         yyterminate();
			       } else { /* restore previous buffer */
			         isdn_include_t* temp = isdn_include_list;
				 
				 if (debug)
				   fprintf(stderr, "Returning to %s ...\n",
				           temp->filename);
			         isdn__delete_buffer(YY_CURRENT_BUFFER);
				 isdn__switch_to_buffer(temp->state);
				 BEGIN(_INCLUDE_);
				 isdn_lloc = temp->location;
				 free(isdn_filename);
				 isdn_filename = temp->filename;
				 isdn_include_list = temp->next;
				 free(temp);
			       }
                             }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 159 "isdnlexer.l"
{ /* eat whitespace in _INCLUDE_ mode */
                               isdn_locate();
                             }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 162 "isdnlexer.l"
{ /* return to normal mode */
                               isdn_locate();
			       BEGIN(INITIAL);
                             }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 166 "isdnlexer.l"
{ /* NAME */
                               isdn_locate();
                               isdn_lval = strdup(isdn_text);
			       return ISDN_TOKEN_NAME;
                             }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 171 "isdnlexer.l"
{ /* whitespace */
                               isdn_locate();
                             }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 174 "isdnlexer.l"
{ /* subsection begin */
                               isdn_locate();
			       BEGIN(INITIAL);
			       return *isdn_text;
			     }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 179 "isdnlexer.l"
{ /* VALUE */
                               isdn_locate();
                               isdn_lval = strdup(isdn_text);
			       isdn_lval = realloc(isdn_lval,
			                           strlen(isdn_text));
			       isdn_lval[strlen(isdn_text) - 1] = '\0';
			       BEGIN(INITIAL);
                               return ISDN_TOKEN_VALUE;
                             }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 188 "isdnlexer.l"
{ /* quoted VALUE */
                               int len = strchr(isdn_text + 1, '"') - isdn_text;
			       
                               isdn_locate();
                               isdn_lval = (char *)malloc(len);
                               strncpy(isdn_lval, isdn_text + 1, len - 1);
                               isdn_lval[len - 1] = '\0';
			       BEGIN(INITIAL);
			       return ISDN_TOKEN_VALUE;
			     }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 198 "isdnlexer.l"
{ /* eat up comments */
                               isdn_locate();
			     }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 201 "isdnlexer.l"
{
                               isdn_locate();
			       BEGIN(_VALUE_);
			       return *isdn_text;
			     }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 206 "isdnlexer.l"
{ /* eat up whitespace */
                               isdn_locate();
			     }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 209 "isdnlexer.l"
{ /* subsection end or NAME bracket */
                               isdn_locate();
			       return *isdn_text;
			     }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 213 "isdnlexer.l"
{ /* real new line */
                               isdn_locate();
			     }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 216 "isdnlexer.l"
{ /* eat up rest */
                               isdn_locate();
			       if (debug) {
			         fprintf(stderr,
				   "isdnlexer: Unrecognized character: %c "
				   "at %d:%d\n",
				   *isdn_text,
				   isdn_lloc.first_line,
				   isdn_lloc.first_column);
			       }
			     }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 228 "isdnlexer.l"
ECHO;
	YY_BREAK
#line 1066 "lex.yy.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed isdn_in at a new source and called
			 * isdn_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = isdn_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( isdn_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * isdn_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of isdn_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					isdn_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			isdn_restart(isdn_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 77 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 77 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 76);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					isdn_restart(isdn_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( isdn_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve isdn_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void isdn_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        isdn_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            isdn__create_buffer(isdn_in,YY_BUF_SIZE );
	}

	isdn__init_buffer(YY_CURRENT_BUFFER,input_file );
	isdn__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void isdn__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		isdn_pop_buffer_state();
	 *		isdn_push_buffer_state(new_buffer);
     */
	isdn_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	isdn__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (isdn_wrap()) processing, but the only time this flag
	 * is looked at is after isdn_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void isdn__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	isdn_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE isdn__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) isdn_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in isdn__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) isdn_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in isdn__create_buffer()" );

	b->yy_is_our_buffer = 1;

	isdn__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with isdn__create_buffer()
 * 
 */
    void isdn__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		isdn_free((void *) b->yy_ch_buf  );

	isdn_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a isdn_restart() or at EOF.
 */
    static void isdn__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	isdn__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then isdn__init_buffer was _probably_
     * called from isdn_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void isdn__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		isdn__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void isdn_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	isdn_ensure_buffer_stack();

	/* This block is copied from isdn__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from isdn__switch_to_buffer. */
	isdn__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void isdn_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	isdn__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		isdn__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void isdn_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)isdn_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)isdn_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE isdn__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) isdn_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in isdn__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	isdn__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to isdn_lex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       isdn__scan_bytes() instead.
 */
YY_BUFFER_STATE isdn__scan_string (yyconst char * yy_str )
{
    
	return isdn__scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to isdn_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE isdn__scan_bytes  (yyconst char * bytes, int  len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) isdn_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in isdn__scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = isdn__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in isdn__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up isdn_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		isdn_text[isdn_leng] = (yy_hold_char); \
		(yy_c_buf_p) = isdn_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		isdn_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int isdn_get_lineno  (void)
{
        
    return isdn_lineno;
}

/** Get the input stream.
 * 
 */
FILE *isdn_get_in  (void)
{
        return isdn_in;
}

/** Get the output stream.
 * 
 */
FILE *isdn_get_out  (void)
{
        return isdn_out;
}

/** Get the length of the current token.
 * 
 */
int isdn_get_leng  (void)
{
        return isdn_leng;
}

/** Get the current token.
 * 
 */

char *isdn_get_text  (void)
{
        return isdn_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void isdn_set_lineno (int  line_number )
{
    
    isdn_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see isdn__switch_to_buffer
 */
void isdn_set_in (FILE *  in_str )
{
        isdn_in = in_str ;
}

void isdn_set_out (FILE *  out_str )
{
        isdn_out = out_str ;
}

int isdn_get_debug  (void)
{
        return isdn__flex_debug;
}

void isdn_set_debug (int  bdebug )
{
        isdn__flex_debug = bdebug ;
}

/* isdn_lex_destroy is for both reentrant and non-reentrant scanners. */
int isdn_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		isdn__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		isdn_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	isdn_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *isdn_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *isdn_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void isdn_free (void * ptr )
{
	free( (char *) ptr );	/* see isdn_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 228 "isdnlexer.l"



/* For portability's sake */
int isdn_wrap() { return 1; }

/*
 * adjusts isdn_lloc according to isdn_text
 */
void isdn_locate() {
  char* temp;

  isdn_lloc.first_line = isdn_lloc.last_line;
  isdn_lloc.first_column = isdn_lloc.last_column;
  
  for (temp = isdn_text; *temp != '\0'; temp++) {
    if (*temp == '\n') {
      ++ isdn_lloc.last_line;
      isdn_lloc.last_column = 1;
    } else {
      ++ isdn_lloc.last_column;
    }
  }
}

/*
 * to be called directly before the parser run
 *
 * on success, isdn_in contains valid FILE* handle, else NULL
 */
void isdn_lexer_init(char* filename) {
  isdn_lloc.first_line = 1;
  isdn_lloc.first_column = 1;
  isdn_lloc.last_line = 1;
  isdn_lloc.last_column = 1;
  isdn_include_list = NULL;
  if (debug)
    fprintf(stderr, "Reading options file: %s ...\n", filename);
  if (!(isdn_in = fopen(filename, "r"))) {
    fprintf(stderr, "Error opening options file %s.\n", filename);
  } else {
    isdn_filename = strdup(filename);
  }
}

/*
 * to be called directly after the parser run
 */
void isdn_lexer_deinit() {
  if (fclose(isdn_in) == EOF) {
    fprintf(stderr, "Warning: Couldn't close options file.\n");
  }
  free(isdn_filename);
}


